#!/bin/bash
#
# Author: ue
# project web page: http://gnomad2.sourceforge.net

# Run this script as root if not already.
chk_root () {

  if [ ! $( id -u ) -eq 0 ]; then
    echo "Please enter root's password."
    exec su -c "${0} ${CMDLN_ARGS}" 
    exit ${?}  
               
  fi

}
chk_root

# Package name
NAME="gnomad2"
# Package version
VERSION="2.9.1"
# Source code URL
SOURCE="http://downloads.sourceforge.net/gnomad2/gnomad2-2.9.1.tar.gz?modtime=1201561660&big_mirror=0"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL README"
# Icon
DIR="48x48"

CWD=$(pwd)
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="50.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Gnomad2 2.9.1
$NAME:
$NAME: Gnomad 2 is a GUI built on top of GTK/GNOME 2, libid3tag, libnjb and  
$NAME: libmtp that makes it possible to transfer tracks and files from/to a
$NAME: Creative Nomad Jukebox (all brands) and MTP devices. It is designed
$NAME: much like an ordinary graphical FTP program.
$NAME: 
END

# Check to see if source is present. If it's not, download it
rm -rf gnomad2-$VERSION
if [ -f gnomad2-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf gnomad2-$VERSION.tar.gz

# building-computer dependent: the number of parallel 'jobs' of 'make'
# 'heavy' computer: 6 build-jobs at once
# numjobs='-j6'
# 'light' computer: 2 build-jobs at once
numjobs='-j2'

# Configure and make
cd gnomad2-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure --prefix=/usr
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/gnomad2-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
mkdir -p $PKG/usr/man/man1
find $PKG/usr/share/man/man1 -type f -exec gzip -9 {} \;
cp -a $PKG/usr/share/man/man1/gnomad2.1.gz $PKG/usr/man/man1 
rm -rf $PKG/usr/share/man

# Menu Compliance
check_for_menu_compliance() {
	if [ -d "$PKG/usr/share/applications" ]; then
		cd $PKG/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$PKG/usr/share/pixmaps" ]; then
					cd $PKG/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $PKG/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $PKG/usr/share/pixmaps)" ]]; then
								rm -rf $PKG/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$PKG/usr/share/icons" ]; then
					cd $PKG/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $PKG/usr/share/icons/hicolor/$DIR/apps
							mv $icons $PKG/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}
check_for_menu_compliance

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
requiredbuilder -z $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.dep

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/gnomad2-$VERSION
rm -rf $PKG
